@@ -13,7 +13,7 @@ class SlippageModel(ABC):
         pass
 
     @abstractmethod
-    def fill_order(self, trade: Trade, **kwargs) -> Trade:
+    def fill_order(self, trade: Trade, **kwargs) -> 'Trade':
         """Simulate slippage on a trade ordered on a specific exchange.
         Arguments:
             trade: The trade executed on the exchange.
